' Program that replicates Table 4 for Belgium for the paper "Nonmarket Time 
' and the Cost of Children", by Christos Koulovatianos, Carsten Schrder, and Ulrich Schmidt
' Journal of Business and Economic Statistics. January 1, 2009, 27(1): 42-51. doi:10.1198/jbes.2009.0004. 

' Code by Christos Koulovatianos, Vienna, March 10, 2007

' DESCRIPTION OF OUTPUT OF THIS PROGRAM 
' This program creates an Eviews workfile, named "Belgiumpool". 
' Go to the workfile "Belgiumpool" and find at the top of all objects of this workfile
' the equation objects named "aspec{i}y{i}with", where i refers to the 
' regression specification (taking values 1, 2, 3, and 4, as in Table 4-paper), 
' and j, taking values 0, 1, and 2, refers to the level of living standard, with 
' "0" corresponding to the reference income level of 500 Euros, "1"
' corresponding to 2,000 Euros, and "2" corresponding to 3,500 Euros.
' Note that the estimates of all personal characteristics of respondents
' also appear in these equation objects (they do not appear in Table 4 
' of the paper). For an explanation of all these control variables read the 
' associated doc file "READ_ME_JBES_Cost_of_Children.doc".

' EXTREMELY IMPORTANT: enter the directory and filename of the Excel
' file with the data within the quotation marks in the command right below. 
' Make sure that this Excel file is CLOSED when you run the program.
' Otherwise, the database will not be loaded in the Eviews workfile.

%directory_and_filename = "c:\JBES_Children\data\Data_Belgium_2002_pooled.xls"

' FOR EXAMPLE: if you place the Excel worksheet 4.0 named 
' "Data_Belgium_2002_pooled.xls" in the directory "c:\temp\",
' then the command above should be:
' %directory_and_filename = "c:\temp\Data_Belgium_2002_pooled.xls"

%npool = "8493" 		' Enter the number of observations in 
			        	' the pooled file

workfile Belgiumpool u %npool 	' Generate a workfile with 
					' undated observations equal	
					' to the size of the pooled file

read(e,a2) %directory_and_filename 26 	' Load the data from the 
					' Excel file (26 variables). 


'NORMALIZE THE REFERENCE INCOME WITH THE POOREST HOUSEHOLD HAVING THE POVERTY LINE
genr reference_y = ref_inc/500
genr number_childre = dummychild_1+dummychild_2+dummychild_3 
genr numberunemp = number_adults-numberemployed
genr ratioae = numberemployed/number_adults

genr dummye = na
genr dummyeu = 0

smpl 1 %npool if ratioae = 1
dummye = 1

smpl 1 %npool if ratioae < 1
dummye = 0

smpl 1 %npool



smpl 1 %npool if number_adults=2 and numberemployed =1
dummyeu = 1

smpl 1 %npool



smpl 1 %npool if number_adults=2 and numberemployed =1
dummyeu = 1

smpl 1 %npool


genr de = 0
smpl 1 %npool if number_adults=1 and numberemployed =1
de = 1
smpl 1 %npool

genr deu = 0
smpl 1 %npool if number_adults=2 and numberemployed =1
deu = 1
smpl 1 %npool

genr dee = 0
smpl 1 %npool if number_adults=2 and numberemployed =2
dee = 1
smpl 1 %npool





'ESTIMATE alpha, gamma AND theta THAT APPEAR IN TABLE 4

for !j = 0 to 2


smpl 1 %npool if reference_y = 1+!j*3

equation aspec1y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre +c(2)*numberemployed)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age

equation aspec2y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre  +c(2)*numberemployed +c(22)*number_childre*dummyeu +c(23)*number_childre*dummye)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age


equation aspec3y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre  +c(20)*number_adults*dummyeu +c(21)*number_adults*dummye +c(22)*number_childre*dummyeu +c(23)*number_childre*dummye)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age

equation aspec4y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre  +c(20)*number_adults*de +c(21)*number_adults*deu +c(22)*number_adults*dee +c(23)*number_childre*de +c(24)*number_childre*deu +c(25)*number_childre*dee)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age

'equation alls2y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre  +c(2)*numberemployed)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age


'equation ally{!j}with1.ls(h) SCALE = (number_adults +c(1)*number_childre +c(2)*numberemployed  +c(21)*number_adults*dummye +c(22)*number_childre*dummyeu +c(23)*number_childre*dummye)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age


'equation allsuy{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre  +c(20)*number_adults*de +c(21)*number_adults*deu +c(22)*number_adults*dee +c(23)*number_childre*de +c(24)*number_childre*deu +c(25)*number_childre*dee)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age


scalar ssrallwithy{!j} = @ssr

equation ally{!j}without.ls(h) SCALE = (number_adults +c(1)*number_childre +c(2)*numberemployed)^c(3)
scalar ssrallwithouty{!j} = @ssr

scalar ftestally{!j} = ((ssrallwithouty{!j}-ssrallwithy{!j})/15)/(ssrallwithy{!j}/(2831-18))
scalar ftestallsigny{!j} = @fdist(ftestally{!j},15,(2831-18))




smpl 1 %npool if (reference_y = 1+!j*3 and numberemployed=0 and number_adults = 1) or (reference_y = 1+!j*3 and numberemployed=0 and number_adults = 2) or (reference_y = 1+!j*3 and numberemployed=1 and number_adults = 2)

'equation u_uu_eu_y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre +c(2)*numberemployed)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age

equation u_uu_eu_y{!j}with.ls(h) SCALE = (number_adults +c(1)*number_childre +c(2)*numberemployed)^c(3)+C(4)*Gender_0_male	+C(5)*partner_1_yes	+C(6)*partner_work	+C(7)*number_children		+C(8)*income_class	+C(9)*unemployed	+C(10)*blue_collar	+C(11)*civil_servant	+C(12)*student	+C(13)*self_employed	+C(14)*pensioner	+C(16)*working_time	+C(17)*education	+C(18)*siblings		+C(19)*age

scalar ssrwithy{!j} = @ssr

equation u_uu_eu{!j}without.ls(h) SCALE = (number_adults +c(1)*number_childre +c(2)*numberemployed)^c(3)
scalar ssrwithouty{!j} = @ssr

scalar ftesty{!j} = ((ssrwithouty{!j}-ssrwithy{!j})/15)/(ssrwithy{!j}/(1639-18))
scalar ftestsigny{!j} = @fdist(ftesty{!j},15,(1639-18))

smpl 1 %npool
next

