' Program that creates Tables 2 and 3 for Germany for the paper "Nonmarket Time 
' and the Cost of Children", by Christos Koulovatianos, Carsten Schrder, and Ulrich Schmidt
' Journal of Business and Economic Statistics. January 1, 2009, 27(1): 42-51. doi:10.1198/jbes.2009.0004. 

' Code by Christos Koulovatianos, Vienna, March 10, 2007

' DESCRIPTION OF OUTPUT OF THIS PROGRAM 
' This program creates two Eviews workfiles, named "Germanypoold" and
' "Germanydesc". Go to the workfile "Germanydesc" and find at the top of 
' all objects of this workfile the tables named "_table2_Germany" and 
' "_table3_Germany". This is the summary of the output of this program, that 
' replicates Tables 2 and 3 (only for Germany), that appears in the paper. 
' In order to check the sources of each entry of these two tables, follow the 
' code below.


' EXTREMELY IMPORTANT: enter the directory and filename of the Excel
' file with the data within the quotation marks in the command right below. 
' Make sure that this Excel file is CLOSED when you run the program.
' Otherwise, the database will not be loaded in the Eviews workfile.

%directory_and_filename = "c:\JBES_Children\data\Data_Germany_2005_pooled.xls"

' FOR EXAMPLE: if you place the Excel worksheet 4.0 named 
' "Data_Germany_2005_pooled.xls" in the directory "c:\temp\",
' then the command above should be:
' %directory_and_filename = "c:\temp\Data_Germany_2005_pooled.xls"

%npool = "9348" 		' Enter the number of observations in 
			        	' the pooled file

workfile Germanypoold u %npool 	' Generate a workfile with 
					' undated observations equal	
					' to the size of the pooled file

read(e,a2) %directory_and_filename 26 	' Load the data from the 
					' Excel file (26 variables). 

'Rename and redefine some variables for convenience


'NORMALIZE THE REFERENCE INCOME WITH THE POOREST HOUSEHOLD HAVING THE POVERTY LINE
genr reference_y = ref_inc/500
genr number_childre = dummychild_1+dummychild_2+dummychild_3 
genr numberunemp = number_adults-numberemployed
genr ratioae = numberemployed/number_adults
genr ey = scale*ref_inc

matrix(4,5) means0 = 0
matrix(4,5) means1 = 0
matrix(4,5) means2 = 0

scalar aa = 0



for !a = 1 to 2		' Start a loop where !a is an index for the number
			' of adults

for !w = 0 to 2

	if !a = 1 and !w  = 2 then
 		!a = 2
		!w = 0
	endif
	
for !c = 0 to 3		' Start a loop where !c is an index for the number
			' of children
 			
if !a = 1 and !w = 0 then	' Eliminate the possibility that a single-non-
		 	' working-adult household is considered (the 
			' scale for this household type is 1)

	if !c = 0 then
	!c = 1		' Go to the case of a single adult with one child
 			
	endif

endif

for !j = 0 to 2


smpl 1 %npool if reference_y = 1+!j*3 and number_adults = !a and numberemployed = !w and number_childre = !c

genr ey{!a}a{!w}w{!c}c{!j}y = ey

stom(ey{!a}a{!w}w{!c}c{!j}y, ey{!a}a{!w}w{!c}c{!j}yv)
store ey{!a}a{!w}w{!c}c{!j}yv





means{!j}(!c+1,!a+!w) = @mean(ey{!a}a{!w}w{!c}c{!j}y) 

scalar aa = aa+1

next
next	
next
next
smpl 1 %npool



%nobs = "164" 		' Enter the number of observations in 
			        	' the pooled file

workfile Germanydesc u %nobs 	' Generate a workfile with 
				' undated observations equal	
				' to the size of the respondents

' Initialize Table 2 for Germany, set its margins, and give it a title
table _Table2_Germany

scalar leftmargin2 = 3
scalar topmargin2 = 8

setcell(_Table2_Germany, 2, (leftmargin2+12)/2-4, "Table 2 -- Germany:  Average stated equivalent incomes (values in Euros)")
setcell(_Table2_Germany, topmargin2-2, 1, "Reference")
setcell(_Table2_Germany, topmargin2-1, 1, "income")

' Initialize Table 3 for Germany, set its margins, and give it a title
table _Table3_Germany

scalar leftmargin3 = 4
scalar topmargin3 = 10

setcell(_Table3_Germany, 2, (leftmargin3+24)/2-1, "Table 3 -- Germany")

scalar n = 164

for !j = 0 to 2

genr ey1a0w0c{!j}y = 500*(1+!j*3)

for !a = 1 to 2		' Start a loop where !a is an index for the number
			' of adults

for !w = 0 to 2

	if !a = 1 and !w  = 2 then
 		!a = 2
		!w = 0
	endif
	
for !c = 0 to 3		' Start a loop where !c is an index for the number
			' of children
 			
if !a = 1 and !w = 0 then	' Eliminate the possibility that a single-non-
		 	' working-adult household is considered (the 
			' scale for this household type is 1)

	if !c = 0 then
	!c = 1		' Go to the case of a single adult with one child
 			
	endif

endif



'smpl 1 %npool if reference_y = 1+!j*3 and number_adults = !a and numberemployed = !w and number_childre = !c

fetch ey{!a}a{!w}w{!c}c{!j}yv
mtos(ey{!a}a{!w}w{!c}c{!j}yv, ey{!a}a{!w}w{!c}c{!j}y)
d ey{!a}a{!w}w{!c}c{!j}yv

scalar n = 164


scalar ey{!a}a{!w}w{!c}c{!j}ymean = @mean(ey{!a}a{!w}w{!c}c{!j}y)
scalar ey{!a}a{!w}w{!c}c{!j}yste = @stdev(ey{!a}a{!w}w{!c}c{!j}y)/n^(1/2)

' Asign values to Table 2

setcell(_Table2_Germany, topmargin2+5+13*!j, 1, 500+1500*!j, 0)

if !c=0 then
	setcell(_Table2_Germany, topmargin2+!j*13+3*!c, 2, "No")
	setcell(_Table2_Germany, topmargin2+!j*13+3*!c+1, 2, "children")

	else
		if !c=1 then
			setcell(_Table2_Germany, topmargin2+!j*13+3*!c, 2, !c, 0)
			setcell(_Table2_Germany, topmargin2+!j*13+3*!c+1, 2, "child")			
			else
				setcell(_Table2_Germany, topmargin2+!j*13+3*!c, 2, !c, 0)
				setcell(_Table2_Germany, topmargin2+!j*13+3*!c+1, 2, "children")			
			
		endif
endif


if !a = 1 then
	setcell(_Table2_Germany, topmargin2+!j*13+3*!c, leftmargin2+2*(!a+!w-1)+1, ey{!a}a{!w}w{!c}c{!j}ymean, 2)
	setcell(_Table2_Germany, topmargin2+!j*13+3*!c+1, leftmargin2+2*(!a+!w-1)+1, ey{!a}a{!w}w{!c}c{!j}yste, 2)
	%str_pe = _Table2_Germany(topmargin2+!j*13+3*!c+1, leftmargin2+2*(!a+!w-1)+1)
	%str_pe ="(" + %str_pe + " )"
	_Table2_Germany(topmargin2+!j*13+3*!c+1, leftmargin2+2*(!a+!w-1)+1) = %str_pe

	if !w = 0 and !j = 0 and !c =1 then
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-5, leftmargin2+2*(!a+!w-1)+1, "N")
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-7, leftmargin2+2*(!a+!w-1)+2, "Singles")
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-5, leftmargin2+2*(!a+!w-1)+3, "W")
	endif

endif

if !a = 2 then
	setcell(_Table2_Germany, topmargin2+!j*13+3*!c, leftmargin2+2*(!a+!w)+1, ey{!a}a{!w}w{!c}c{!j}ymean, 2)
	setcell(_Table2_Germany, topmargin2+!j*13+3*!c+1, leftmargin2+2*(!a+!w)+1, ey{!a}a{!w}w{!c}c{!j}yste, 2)
	%str_pe = _Table2_Germany(topmargin2+!j*13+3*!c+1, leftmargin2+2*(!a+!w)+1)
	%str_pe ="(" + %str_pe + " )"
	_Table2_Germany(topmargin2+!j*13+3*!c+1, leftmargin2+2*(!a+!w)+1) = %str_pe

	if !w = 0 and !j = 0 and !c =0 then
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-2, leftmargin2+2*(!a+!w)+1, "NN")
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-2, leftmargin2+2*(!a+!w)+3, "WN")
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-4, leftmargin2+2*(!a+!w)+3, "Couples")
		setcell(_Table2_Germany, topmargin2+!j*13+3*!c-2, leftmargin2+2*(!a+!w)+5, "WW")
	endif
endif


'means{!j}(!c+1,!a+!w) = @mean(ey{!a}a{!w}w{!c}c{!j}y) 

if !w>0 then 

for !ww = (!w-1) to (!w-1)

genr dey{!a}a{!ww}_{!w}w{!c}c{!j}y = -ey{!a}a{!ww}w{!c}c{!j}y+ey{!a}a{!w}w{!c}c{!j}y

'Set the names of descriptive statistics
setcell(_Table3_Germany, topmargin3+!j*6+1, leftmargin3-2, "Mean")
setcell(_Table3_Germany, topmargin3+!j*6+2, leftmargin3-2, "Median")
setcell(_Table3_Germany, topmargin3+!j*6+3, leftmargin3-2, "Std. Error")
setcell(_Table3_Germany, topmargin3+!j*6+4, leftmargin3-2, "Wilcoxon")
setcell(_Table3_Germany, topmargin3+!j*6+5, leftmargin3-2, "p-value")

'Set the title and levels of reference incomes
setcell(_Table3_Germany, topmargin3-2, 1, "reference")
setcell(_Table3_Germany, topmargin3-1, 1, "income")
setcell(_Table3_Germany, topmargin3+!j*6+3, 1, 500+!j*1500, 0)

'Specify the number of children in words for Table 3
if !c=0 then
	setcell(_Table3_Germany, topmargin3-2, leftmargin3+2*!c+(!a+!ww-1)*8, "No")
	setcell(_Table3_Germany, topmargin3-1, leftmargin3+2*!c+(!a+!ww-1)*8, "children")

else

	if !c=1 then
		setcell(_Table3_Germany, topmargin3-2, leftmargin3+2*!c+(!a+!ww-1)*8, !c, 0)
		setcell(_Table3_Germany, topmargin3-1, leftmargin3+2*!c+(!a+!ww-1)*8, "child")
	
		else
			setcell(_Table3_Germany, topmargin3-2, leftmargin3+2*!c+(!a+!ww-1)*8, !c, 0)
			setcell(_Table3_Germany, topmargin3-1, leftmargin3+2*!c+(!a+!ww-1)*8, "children")

	endif
endif

scalar dey{!a}a{!ww}_{!w}w{!c}c{!j}ymean = @mean(dey{!a}a{!ww}_{!w}w{!c}c{!j}y)
scalar dey{!a}a{!ww}_{!w}w{!c}c{!j}ymedian = @median(dey{!a}a{!ww}_{!w}w{!c}c{!j}y)
scalar dey{!a}a{!ww}_{!w}w{!c}c{!j}yste = @stdev(dey{!a}a{!ww}_{!w}w{!c}c{!j}y)/n^(1/2)

setcell(_Table3_Germany, topmargin3+!j*6+1, leftmargin3+2*!c+(!a+!ww-1)*8, dey{!a}a{!ww}_{!w}w{!c}c{!j}ymean, 2)
setcell(_Table3_Germany, topmargin3+!j*6+2, leftmargin3+2*!c+(!a+!ww-1)*8, dey{!a}a{!ww}_{!w}w{!c}c{!j}ymedian, 2)
setcell(_Table3_Germany, topmargin3+!j*6+3, leftmargin3+2*!c+(!a+!ww-1)*8, dey{!a}a{!ww}_{!w}w{!c}c{!j}yste, 2)

%str_pe =_Table3_Germany(topmargin3+!j*6+3, leftmargin3+2*!c+(!a+!ww-1)*8)
%str_pe ="(" + %str_pe + " )"
_Table3_Germany(topmargin3+!j*6+3, leftmargin3+2*!c+(!a+!ww-1)*8) = %str_pe


' ****************************** strings for the lines of the table
if !c = 0 and (!a+!ww-1) = 0 then  
	setcell(_Table3_Germany, topmargin3-6, leftmargin3+2*!c+(!a+!ww-1)*8+3, "Singles")
	setcell(_Table3_Germany, topmargin3-5, leftmargin3+2*!c+(!a+!ww-1)*8+3, "N to W")
	setcell(_Table3_Germany, topmargin3-4, leftmargin3+2*!c+(!a+!ww-1)*8+1, "  (restrictive reduction in NMTE)")
endif

if !c = 0 and (!a+!ww-1) = 1 then  
	setcell(_Table3_Germany, topmargin3-6, leftmargin3+2*!c+(!a+!ww-1)*8+7, "Couples")
	setcell(_Table3_Germany, topmargin3-5, leftmargin3+2*!c+(!a+!ww-1)*8+2, "     NN to WN")
	setcell(_Table3_Germany, topmargin3-4, leftmargin3+2*!c+(!a+!ww-1)*8+1, " (nonrestrictive reduction in NMTE)")
endif


if !c = 0 and (!a+!ww-1) = 2 then  
	setcell(_Table3_Germany, topmargin3-5, leftmargin3+2*!c+(!a+!ww-1)*8+2, "     WN to WW")
	setcell(_Table3_Germany, topmargin3-4, leftmargin3+2*!c+(!a+!ww-1)*8+1, "  (restrictive reduction in NMTE)")
endif

' ****************************** end strings for the lines of the table

next		' end for !ww
endif





if !c > 0 and !w>0 then 

for !cc = (!c-1) to (!c-1)
for !ww = (!w-1) to (!w-1)
	genr ddey{!a}a{!ww}_{!w}w{!c}_{!cc}c{!j}y = dey{!a}a{!ww}_{!w}w{!c}c{!j}y - dey{!a}a{!ww}_{!w}w{!cc}c{!j}y

	freeze(gddey{!a}a{!ww}_{!w}w{!c}_{!cc}c{!j}y) ddey{!a}a{!ww}_{!w}w{!c}_{!cc}c{!j}y.teststat(med=0)


vector(2,1) temp1

temp1(1) = gddey{!a}a{!ww}_{!w}w{!c}_{!cc}c{!j}y(12, 3)
temp1(2) = gddey{!a}a{!ww}_{!w}w{!c}_{!cc}c{!j}y(12, 4)

setcell(_Table3_Germany, topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1, temp1(1), 2)

if temp1(2) < .01 then

%str_pe =_Table3_Germany(topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1)
%str_pe = %str_pe + "***"
_Table3_Germany(topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1) = %str_pe

else
	if temp1(2) < .05 then

		%str_pe =_Table3_Germany(topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1)
		%str_pe = %str_pe + "**"
		_Table3_Germany(topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1) = %str_pe
	
	else
		if temp1(2) < .10 then
			%str_pe =_Table3_Germany(topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1)
			%str_pe = %str_pe + "*"
			_Table3_Germany(topmargin3+!j*6+4, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1) = %str_pe
		endif
	endif
endif

setcell(_Table3_Germany, topmargin3+!j*6+5, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1, temp1(2), 2)
%str_pe =_Table3_Germany(topmargin3+!j*6+5, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1)
%str_pe ="[" + %str_pe + " ]"
_Table3_Germany(topmargin3+!j*6+5, leftmargin3+2*(!c-1)+(!a+!ww-1)*8+1) = %str_pe


next	'end for !ww
next	'end for !cc
endif


next		' end for !c loop


next	'end for !w
next	'end for !a
next	'end for !j


'Set lines and notes for the tables

_Table2_Germany.setwidth(2:15) 7
setline(_Table2_Germany, 3)
setline(_Table2_Germany, topmargin2+40)
_Table2_Germany.setlines(a45:l45) +b
setcell(_Table2_Germany, topmargin2+38, 1, "NOTE:     		 Standard errors in parentheses; reference income in Euros; each N denotes a ")
setcell(_Table2_Germany, topmargin2+39, 2, "nonworking adult; each W denotes a (full-time) working adult")
_Table2_Germany.setlines(d6:f6) +b
_Table2_Germany.setlines(h6:l6) +b

setline(_Table3_Germany, 3)
setcell(_Table3_Germany, topmargin3+20, 2, "NOTE: reference income in Euros; *** denotes significance at the 1% level;** denotes significance at the 5% level; * denotes significance at the 10% level")
setline(_Table3_Germany, topmargin3+22)
_Table3_Germany.setlines(a28:z28) +b

_Table3_Germany.setlines(d4:j4) +b
_Table3_Germany.setlines(d6:j6) +b

_Table3_Germany.setlines(l4:z4) +b

_Table3_Germany.setlines(l6:r6) +b
_Table3_Germany.setlines(t6:z6) +b

_Table3_Germany.setwidth(2:26) 5.5

